#include <QMouseEvent>
#include <QDebug>
#include "settings.h"

#include "externalbrowser.h"

ExternalBrowser::ExternalBrowser(PlaylistItem *item, QWidget *parent)
    : QWidget(parent)
    , Runnable(item->time())
{
    m_uri = item->uri();
    QObject::connect(&player, SIGNAL(finished(int)),
                     this   , SLOT(onMediaEndReached(int)));
}

void ExternalBrowser::onMediaEndReached(int)
{
    Q_EMIT end();
}

bool ExternalBrowser::startImpl(void)
{
    Settings *settings;
    settings = Settings::load();
    QString cmd = settings->get("main/external_browser_cmd").toString();
    QStringList cmdLst = cmd.split(' ');

    QStringList args;
    for (int i = 1; i < cmdLst.length(); ++i)
        args << QString(cmdLst.at(i)).replace("%u", m_uri);

    qDebug() << "Running external browser:" << cmdLst.at(0) << args;
    player.start(cmdLst.at(0), args);
    player.waitForStarted();

    return true;
}


bool ExternalBrowser::stopImpl(void)
{
    QObject::disconnect(
                &player, SIGNAL(finished(int)),
                this   , SLOT(onMediaEndReached(int)));
    player.terminate();
    player.waitForFinished();
    return true;
}


bool ExternalBrowser::onTimeoutImpl(void)
{
    Q_EMIT end();
    return true;
}


void ExternalBrowser::pauseImpl(void) {}


void ExternalBrowser::resumeImpl(void) {}


void ExternalBrowser::mousePressEvent(QMouseEvent* event)
{
    if (event->button() == Qt::RightButton)
        Q_EMIT rightclick();
}
