#include <QPixmap>
#include <QRect>
#include <QPalette>
#include <QDesktopWidget>
#include <settings.h>
#include <QMouseEvent>
#include <QtGui>

#include "image.h"

Image::Image(PlaylistItem *item, QWidget *parent)
    : QLabel(parent)
    , Runnable(item->time())
{
    m_uri = item->uri();
    setAlignment(Qt::AlignCenter);
    setBlackBackground();
    QRect g = qobject_cast<QWidget *>(QLabel::parent())->geometry();
    p_w = g.width();
    p_h = g.height();
    buildPixmap();
}


void Image::setBlackBackground(void)
{
    QPalette p;
    p.setColor(QPalette::Background, Qt::black);
    QLabel::setAutoFillBackground(true);
    QLabel::setPalette(p);
}


void Image::buildPixmap(void)
{
    float s_w, s_h;
    QString path = m_uri.mid(7);
    QPixmap source(path);
    if (source.isNull())
    {
        setPixmap(source);
        return;
    }
    s_w = source.width();
    s_h = source.height();

    qDebug()<<p_w<<p_h<<s_w<<s_h;
    Settings  *settings = Settings::load();
    if(settings->get("slideshow/resize").toBool()){
        pixmap = source.scaled(p_w,p_h,Qt::KeepAspectRatio, Qt::SmoothTransformation);
    }
    else if ((s_w <= p_w) && (s_h <= p_h)){
        pixmap = source;
    }
    else{
        pixmap = source.scaled(p_w,p_h,Qt::KeepAspectRatio, Qt::SmoothTransformation);
    }
    setPixmap(pixmap);
}

bool Image::startImpl(void)
{
    if (pixmap.isNull())
    {
        Q_EMIT end();
        return false;
    }
    return true;
}

bool Image::stopImpl(void)
{
    pixmap = NULL;
    return true;
}

bool Image::onTimeoutImpl(void) {Q_EMIT end();return true;}

void Image::pauseImpl(void) {}


void Image::resumeImpl(void) {}

void Image::mousePressEvent(QMouseEvent* event)
{
    if (event->button() == Qt::RightButton)
        Q_EMIT rightclick();
}
