#include <set>

#include <QVBoxLayout>
#include <QDebug>
#include <QMouseEvent>
#include <QProcess>

#include "./video/externalimpl.h"
#include "./video/vlcimpl.h"


Video::Video(PlaylistItem *item, QWidget *parent)
    : QWidget(parent)
    , Runnable(item->time())
{
    Settings* settings = Settings::load();

    if (settings->get("slideshow/external_player").toBool())
    {
        QString command =
                settings->get("slideshow/external_player_cmd").toString();

        QStringList cmd;
        if (!command.isEmpty())
        {
            qDebug() << "Using external command:" << command;
            cmd = command.split(' ');
        }
        else
        {
            #ifdef __arm__
            if (settings->get("slideshow/mute").toBool())
                cmd << "omxplayer" << "--vol" << "-10000" << "-b" << "%f";
            else
                cmd << "omxplayer" << "-b" << "%f";
            #else
            cmd << "mplayer" << "-fs" << "%f";
            #endif
        }

        m_impl = new ExternalVideoImpl(cmd, item, this);
    }
    else
        m_impl = new VLCVideoImpl(item, this);
}


Video::~Video(void)
{ delete m_impl; }


bool Video::startImpl(void)
{ return m_impl->start(); }


bool Video::stopImpl(void)
{ return m_impl->stop(); }


bool Video::onTimeoutImpl(void)
{ return m_impl->onTimeout(); }


void Video::pauseImpl(void)
{ m_impl->pause(); }


void Video::resumeImpl(void)
{ m_impl->resume(); }


void Video::mousePressEvent(QMouseEvent* event)
{
    if (event->button() == Qt::RightButton)
        Q_EMIT rightclick();
}
