#include "./externalimpl.h"


#include <QProcess>
#include <QDebug>


ExternalVideoImpl::ExternalVideoImpl(
        QStringList const& command, PlaylistItem* item, Video* p)
    : VideoImpl(item, p)
    , _command(command)
    , _process(NULL)
    , _display(NULL)
{
    VideoImpl::parent()->setAutoFillBackground(true);
    QPalette plt;
    plt.setColor(QPalette::Window, Qt::black);
    VideoImpl::parent()->setPalette(plt);
}


ExternalVideoImpl::~ExternalVideoImpl(void)
{
    stop();
}


bool ExternalVideoImpl::start(void)
{
    stop();

    _process = new QProcess();
    QObject::connect(
                _process, SIGNAL(finished(int)),
                this, SLOT(onMediaEndReached(int)));

    QStringList args;
    QString file(uri());
    file.replace("file://", "");
    QStringList::const_iterator
            it = ++_command.begin(), itEnd = _command.end();
    for (; it != itEnd; ++it)
        args << QString(*it).replace("%f", file);

    qDebug() << "Launching command:" << _command.at(0) << args;
    _process->start(_command.at(0), args);
    _process->waitForStarted();

    return true;
}


bool ExternalVideoImpl::stop(void)
{
    if (_process)
    {
        QObject::disconnect(
                    _process, SIGNAL(finished(int)),
                    this, SLOT(onMediaEndReached(int)));
        _process->kill();
        _process->deleteLater();
        _process = NULL;
    }

    return true;
}


bool ExternalVideoImpl::onTimeout(void)
{ end(); return true; }


void ExternalVideoImpl::onMediaEndReached(int)
{
    if (_process)
    {
        QObject::disconnect(
                    _process, SIGNAL(finished(int)),
                    this, SLOT(onMediaEndReached(int)));
        _process->deleteLater();
        _process = NULL;
    }

    Q_EMIT end();
}


#include "externalimpl.moc"
