#include "mimedb.h"

QMap<QString, QString> MimeDb::map = init();

QString MimeDb::get(QString ext)
{
    ext = ext.toLower();
    if (map.contains(ext))
        return map[ext];
    else
        return QString();
};

QString MimeDb::getForFileName(QString filename)
{
    QStringList spl = filename.split(".");
    return MimeDb::get(spl.at(spl.size() - 1));
}

QMap<QString, QString> MimeDb::init() {
    QMap<QString, QString> map;

    map["scm"] = "text/x-scheme";
    map["gv"] = "text/vnd.graphviz";
    map["gp"] = "application/x-gnuplot";
    map["kexis"] = "application/x-kexiproject-shortcut";
    map["gz"] = "image/x-gzeps";
    map["gg"] = "application/x-sms-rom";
    map["sldm"] = "application/vnd.ms-powerpoint.slide.macroEnabled.12";
    map["mp4"] = "video/mp4";
    map["alz"] = "application/x-alz";
    map["gb"] = "application/x-gameboy-rom";
    map["wvc"] = "audio/x-wavpack-correction";
    map["go"] = "text/x-go";
    map["kexic"] = "application/x-kexi-connectiondata";
    map["mng"] = "video/x-mng";
    map["sr2"] = "image/x-sony-sr2";
    map["xlsb"] = "application/vnd.ms-excel.sheet.binary.macroEnabled.12";
    map["xml"] = "application/xml";
    map["tr"] = "text/troff";
    map["ts"] = "video/mp2t";
    map["vcs"] = "text/calendar";
    map["srf"] = "image/x-sony-srf";
    map["wml"] = "text/vnd.wap.wml";
    map["wma"] = "audio/x-ms-wma";
    map["wmf"] = "image/x-wmf";
    map["me"] = "text/x-troff-me";
    map["sylk"] = "text/spreadsheet";
    map["g3"] = "image/fax-g3";
    map["smi"] = "application/x-sami";
    map["vlc"] = "audio/x-mpegurl";
    map["mp+"] = "audio/x-musepack";
    map["mpp"] = "audio/x-musepack";
    map["rm"] = "application/vnd.rn-realmedia";
    map["gplt"] = "application/x-gnuplot";
    map["lrz"] = "application/x-lrzip-compressed-tar";
    map["pef"] = "image/x-pentax-pef";
    map["clpi"] = "video/mp2t";
    map["gf"] = "application/x-tex-gf";
    map["gnucash"] = "application/x-gnucash";
    map["dia"] = "application/x-dia-diagram";
    map["kmz"] = "application/vnd.google-earth.kmz";
    map["anim[1-9j]"] = "video/x-anim";
    map["p"] = "text/x-pascal";
    map["AUTHORS"] = "text/x-authors";
    map["pbm"] = "image/x-portable-bitmap";
    map["mp2"] = "video/mpeg";
    map["der"] = "application/x-x509-ca-cert";
    map["mp3"] = "audio/mpeg";
    map["vhdl"] = "text/x-vhdl";
    map["odp"] = "application/vnd.oasis.opendocument.presentation";
    map["htm"] = "text/html";
    map["ods"] = "application/vnd.oasis.opendocument.spreadsheet";
    map["odt"] = "application/vnd.oasis.opendocument.text";
    map["tex"] = "text/x-tex";
    map["odi"] = "application/vnd.oasis.opendocument.image";
    map["dcm"] = "application/dicom";
    map["qml"] = "text/x-qml";
    map["oda"] = "application/oda";
    map["odb"] = "application/vnd.oasis.opendocument.database";
    map["odc"] = "application/vnd.oasis.opendocument.chart";
    map["odf"] = "application/vnd.oasis.opendocument.formula";
    map["odg"] = "application/vnd.oasis.opendocument.graphics";
    map["fli"] = "video/x-flic";
    map["bdf"] = "application/x-font-bdf";
    map["sub"] = "text/x-subviewer";
    map["gnc"] = "application/x-gnucash";
    map["nef"] = "image/x-nikon-nef";
    map["sun"] = "image/x-sun-raster";
    map["cgm"] = "image/cgm";
    map["m2ts"] = "video/mp2t";
    map["abw"] = "application/x-abiword";
    map["kud"] = "application/x-kugar";
    map["kdc"] = "image/x-kodak-kdc";
    map["nes"] = "application/x-nes-rom";
    map["med"] = "audio/x-mod";
    map["vala"] = "text/x-vala";
    map["eif"] = "text/x-eiffel";
    map["j2k"] = "image/jp2";
    map["wmx"] = "audio/x-ms-asx";
    map["cab"] = "application/vnd.ms-cab-compressed";
    map["flc"] = "video/x-flic";
    map["ocl"] = "text/x-ocl";
    map["gnumeric"] = "application/x-gnumeric";
    map["wdb"] = "application/vnd.ms-works";
    map["hdf4"] = "application/x-hdf";
    map["hdf5"] = "application/x-hdf";
    map["pict"] = "image/x-pict";
    map["djv"] = "image/vnd.djvu";
    map["m3u"] = "application/vnd.apple.mpegurl";
    map["cert"] = "application/x-x509-ca-cert";
    map["rdf"] = "application/rdf+xml";
    map["3ga"] = "video/3gpp";
    map["icns"] = "image/x-icns";
    map["pntg"] = "image/x-macpaint";
    map["wim"] = "application/x-ms-wim";
    map["wmv"] = "video/x-ms-wmv";
    map["sgi"] = "image/x-sgi";
    map["apk"] = "application/vnd.android.package-archive";
    map["sgm"] = "text/sgml";
    map["sgl"] = "application/vnd.stardivision.writer";
    map["README*"] = "text/x-readme";
    map["txt"] = "text/x-cmake";
    map["wbmp"] = "image/vnd.wap.wbmp";
    map["sgf"] = "application/x-go-sgf";
    map["dng"] = "image/x-adobe-dng";
    map["mmf"] = "application/x-smaf";
    map["vob"] = "video/mpeg";
    map["zip"] = "application/zip";
    map["msx"] = "application/x-msx-rom";
    map["epsf"] = "image/x-eps";
    map["lws"] = "image/x-lws";
    map["chm"] = "application/vnd.ms-htmlhelp";
    map["perl"] = "application/x-perl";
    map["m4"] = "application/x-m4";
    map["ult"] = "audio/x-mod";
    map["msi"] = "application/x-msi";
    map["gedcom"] = "application/x-gedcom";
    map["tk"] = "text/x-tcl";
    map["pfa"] = "application/x-font-type1";
    map["fb2"] = "application/x-fictionbook+xml";
    map["wvx"] = "audio/x-ms-asx";
    map["pfb"] = "application/x-font-type1";
    map["ooc"] = "text/x-ooc";
    map["gvp"] = "text/x-google-video-pointer";
    map["wvp"] = "audio/x-wavpack";
    map["flac"] = "audio/flac";
    map["pfx"] = "application/x-pkcs12";
    map["psflib"] = "audio/x-psflib";
    map["vcard"] = "text/vcard";
    map["tpic"] = "image/x-tga";
    map["md"] = "text/x-markdown";
    map["ldif"] = "text/x-ldif";
    map["f"] = "text/x-fortran";
    map["mm"] = "text/x-troff-mm";
    map["ml"] = "text/x-ocaml";
    map["mo"] = "application/x-gettext-translation";
    map["cap"] = "application/vnd.tcpdump.pcap";
    map["flw"] = "application/x-kivio";
    map["flv"] = "video/x-flv";
    map["gcrd"] = "text/vcard";
    map["tnf"] = "application/vnd.ms-tnef";
    map["ms"] = "text/x-troff-ms";
    map["v"] = "text/x-verilog";
    map["erl"] = "text/x-erlang";
    map["oleo"] = "application/x-oleo";
    map["deb"] = "application/x-deb";
    map["qtvr"] = "video/quicktime";
    map["spx"] = "audio/x-speex";
    map["RMAIL"] = "message/x-gnu-rmail";
    map["xcf"] = "image/x-xcf";
    map["INSTALL"] = "text/x-install";
    map["tar"] = "application/x-tar";
    map["mpg"] = "video/mpeg";
    map["taz"] = "application/x-compressed-tar";
    map["mpe"] = "video/mpeg";
    map["spl"] = "application/x-shockwave-flash";
    map["glade"] = "application/x-glade";
    map["COPYING"] = "text/x-copying";
    map["dxf"] = "image/vnd.dxf";
    map["spc"] = "application/x-pkcs7-certificates";
    map["spd"] = "application/x-font-speedo";
    map["mpc"] = "audio/x-musepack";
    map["sis"] = "application/vnd.symbian.install";
    map["afm"] = "application/x-font-afm";
    map["chrt"] = "application/x-kchart";
    map["csh"] = "application/x-csh";
    map["sit"] = "application/x-stuffit";
    map["wax"] = "audio/x-ms-asx";
    map["ent"] = "application/xml-external-parsed-entity";
    map["dwg"] = "image/vnd.dwg";
    map["arj"] = "application/x-arj";
    map["sid"] = "audio/prs.sid";
    map["sik"] = "application/x-trash";
    map["xhtml"] = "application/xhtml+xml";
    map["CSSL"] = "text/css";
    map["mpl"] = "video/mp2t";
    map["css"] = "text/css";
    map["snd"] = "audio/basic";
    map["cpio"] = "application/x-cpio";
    map["icc"] = "application/vnd.iccprofile";
    map["mab"] = "application/x-markaby";
    map["divx"] = "video/x-msvideo";
    map["fits"] = "image/fits";
    map["fl"] = "application/x-fluid";
    map["siv"] = "application/sieve";
    map["a"] = "application/x-archive";
    map["lha"] = "application/x-lha";
    map["ss"] = "text/x-scheme";
    map["sv"] = "text/x-svsrc";
    map["sk"] = "image/x-skencil";
    map["mgp"] = "application/x-magicpoint";
    map["so"] = "application/x-sharedlib";
    map["lhz"] = "application/x-lhz";
    map["ttx"] = "application/x-font-ttx";
    map["themepack"] = "application/x-windows-themepack";
    map["jpeg"] = "image/jpeg";
    map["rw2"] = "image/x-panasonic-raw2";
    map["jng"] = "image/x-jng";
    map["ttc"] = "application/x-font-ttf";
    map["tta"] = "audio/x-tta";
    map["ttf"] = "application/x-font-ttf";
    map["pcx"] = "image/x-pcx";
    map["ime"] = "text/x-iMelody";
    map["la"] = "application/x-shared-library-la";
    map["wrl"] = "model/vrml";
    map["3ds"] = "image/x-3ds";
    map["wri"] = "application/x-mswrite";
    map["yaml"] = "application/x-yaml";
    map["vtt"] = "text/vtt";
    map["pcl"] = "application/vnd.hp-pcl";
    map["xliff"] = "application/x-xliff";
    map["pcf"] = "application/x-cisco-vpn-settings";
    map["pcd"] = "image/x-photo-cd";
    map["ly"] = "text/x-lilypond";
    map["pptx"] = "application/vnd.openxmlformats-officedocument.presentationml.presentation";
    map["docx"] = "application/vnd.openxmlformats-officedocument.wordprocessingml.document";
    map["mxu"] = "video/vnd.mpegurl";
    map["fig"] = "image/x-xfig";
    map["p10"] = "application/pkcs10";
    map["karbon"] = "application/x-karbon";
    map["p12"] = "application/x-pkcs12";
    map["pptm"] = "application/vnd.ms-powerpoint.presentation.macroEnabled.12";
    map["lzo"] = "application/x-tzo";
    map["docm"] = "application/vnd.ms-word.document.macroEnabled.12";
    map["mxf"] = "application/mxf";
    map["qt"] = "video/quicktime";
    map["s3m"] = "audio/x-s3m";
    map["kpr"] = "application/x-kpresenter";
    map["xll"] = "application/vnd.ms-excel";
    map["kpt"] = "application/x-kpresenter";
    map["f4v"] = "video/mp4";
    map["nfo"] = "text/x-nfo";
    map["xlf"] = "application/x-xliff";
    map["xld"] = "application/vnd.ms-excel";
    map["xlc"] = "application/vnd.ms-excel";
    map["xla"] = "application/vnd.ms-excel";
    map["f4a"] = "audio/mp4";
    map["CRASHED"] = "application/x-abiword";
    map["iff"] = "image/x-iff";
    map["f4b"] = "audio/x-m4b";
    map["h"] = "text/x-chdr";
    map["xlw"] = "application/vnd.ms-excel";
    map["xlt"] = "application/vnd.ms-excel";
    map["xls"] = "application/vnd.ms-excel";
    map["kpm"] = "application/x-kpovmodeler";
    map["cc"] = "text/x-c++src";
    map["el"] = "text/x-emacs-lisp";
    map["mdi"] = "image/vnd.ms-modi";
    map["jp2"] = "image/jp2";
    map["mdb"] = "application/vnd.ms-access";
    map["gtar"] = "application/x-tar";
    map["ez"] = "application/andrew-inset";
    map["patch"] = "text/x-patch";
    map["es"] = "application/ecmascript";
    map["out"] = "application/x-profile";
    map["lzma"] = "application/x-lzma-compressed-tar";
    map["rv"] = "video/vnd.rn-realvideo";
    map["rp"] = "image/vnd.rn-realpix";
    map["vcf"] = "text/vcard";
    map["m2t"] = "video/mp2t";
    map["GNUmakefile"] = "text/x-makefile";
    map["sms"] = "application/x-sms-rom";
    map["rej"] = "text/x-reject";
    map["dsl"] = "text/x-dsl";
    map["sml"] = "application/smil";
    map["vct"] = "text/vcard";
    map["ra"] = "audio/vnd.rn-realaudio";
    map["rb"] = "application/x-ruby";
    map["smf"] = "application/vnd.stardivision.math";
    map["smd"] = "application/vnd.stardivision.mail";
    map["smc"] = "application/x-snes-rom";
    map["reg"] = "text/x-ms-regedit";
    map["ass"] = "text/x-ssa";
    map["asp"] = "application/x-asp";
    map["rle"] = "image/rle";
    map["asx"] = "audio/x-ms-asx";
    map["asc"] = "text/plain";
    map["mml"] = "application/mathml+xml";
    map["asf"] = "video/x-ms-asf";
    map["orf"] = "image/x-olympus-orf";
    map["egon"] = "application/x-egon";
    map["ora"] = "image/openraster";
    map["java"] = "text/x-java";
    map["pkipath"] = "application/pkix-pkipath";
    map["xpm"] = "image/x-xpixmap";
    map["midi"] = "audio/midi";
    map["ltx"] = "text/x-tex";
    map["iso"] = "application/x-cd-image";
    map["shn"] = "application/x-shorten";
    map["xul"] = "application/vnd.mozilla.xul+xml";
    map["gif"] = "image/gif";
    map["xi"] = "audio/x-xi";
    map["jpc"] = "image/jp2";
    map["xm"] = "audio/x-xm";
    map["pgn"] = "application/x-chess-pgn";
    map["pgm"] = "image/x-portable-graymap";
    map["xz"] = "application/x-xzpdf";
    map["kexi"] = "application/x-kexiproject-sqlite3";
    map["par2"] = "application/x-par2";
    map["pgp"] = "application/pgp-encrypted";
    map["kfo"] = "application/x-kformula";
    map["wpg"] = "application/x-wpg";
    map["kon"] = "application/x-kontour";
    map["gpg"] = "application/pgp-encrypted";
    map["makefile"] = "text/x-makefile";
    map["siag"] = "application/x-siag";
    map["potm"] = "application/vnd.ms-powerpoint.template.macroEnabled.12";
    map["toc"] = "application/x-cdrdao-toc";
    map["man"] = "application/x-troff-man";
    map["ogx"] = "application/ogg";
    map["ogv"] = "video/ogg";
    map["ads"] = "text/x-adasrc";
    map["ogm"] = "video/x-ogm+ogg";
    map["sam"] = "application/x-amipro";
    map["pnm"] = "image/x-portable-anymap";
    map["tlrz"] = "application/x-lrzip-compressed-tar";
    map["ogg"] = "video/x-theora+ogg";
    map["BLEND"] = "application/x-blender";
    map["png"] = "image/png";
    map["rss"] = "application/rss+xml";
    map["std"] = "application/vnd.sun.xml.draw.template";
    map["aac"] = "audio/mp4";
    map["stc"] = "application/vnd.sun.xml.calc.template";
    map["kino"] = "application/smil";
    map["sti"] = "application/vnd.sun.xml.impress.template";
    map["dtd"] = "application/xml-dtd";
    map["nzb"] = "application/x-nzb";
    map["stw"] = "application/vnd.sun.xml.writer.template";
    map["torrent"] = "application/x-bittorrent";
    map["mov"] = "video/quicktime";
    map["odm"] = "application/vnd.oasis.opendocument.text-master";
    map["raf"] = "image/x-fuji-raf";
    map["602"] = "application/x-t602";
    map["*~"] = "application/x-trash";
    map["*,v"] = "text/plain";
    map["prc"] = "application/x-palm-database";
    map["ram"] = "application/ram";
    map["ani"] = "application/x-navi-animation";
    map["raw"] = "image/x-panasonic-raw";
    map["rar"] = "application/x-rar";
    map["ras"] = "image/x-cmu-raster";
    map["uni"] = "audio/x-mod";
    map["anx"] = "application/annodex";
    map["sav"] = "application/x-spss-sav";
    map["rax"] = "audio/vnd.rn-realaudio";
    map["bib"] = "text/x-bibtex";
    map["bz2"] = "image/x-compressed-xcf";
    map["mid"] = "audio/midi";
    map["mif"] = "application/x-mif";
    map["fxm"] = "video/x-javafx";
    map["sh"] = "application/x-shellscript";
    map["meta4"] = "application/metalink4+xml";
    map["lhs"] = "text/x-literate-haskell";
    map["wcm"] = "application/vnd.ms-works";
    map["minipsf"] = "audio/x-minipsf";
    map["xltx"] = "application/vnd.openxmlformats-officedocument.spreadsheetml.template";
    map["kar"] = "audio/midi";
    map["mpeg"] = "video/mpeg";
    map["awk"] = "application/x-awk";
    map["sisx"] = "x-epoc/x-sisx-app";
    map["pyo"] = "application/x-python-bytecode";
    map["*%"] = "application/x-trash";
    map["pyc"] = "application/x-python-bytecode";
    map["class"] = "application/x-java";
    map["epub"] = "application/epub+zip";
    map["latex"] = "text/x-tex";
    map["exe"] = "application/x-ms-dos-executable";
    map["axv"] = "video/annodex";
    map["url"] = "application/x-mswinurl";
    map["doc"] = "application/msword";
    map["mrw"] = "image/x-minolta-mrw";
    map["m"] = "text/x-matlab";
    map["ks"] = "application/x-java-keystore";
    map["bdm"] = "video/mp2t";
    map["axa"] = "audio/annodex";
    map["exr"] = "image/x-exr";
    map["blend"] = "application/x-blender";
    map["dot"] = "text/vnd.graphviz";
    map["pkr"] = "application/pgp-keys";
    map["cdf"] = "application/x-netcdf";
    map["rtf"] = "application/rtf";
    map["669"] = "audio/x-mod";
    map["atom"] = "application/atom+xml";
    map["ufraw"] = "application/x-ufraw";
    map["dbf"] = "application/x-dbf";
    map["wsgi"] = "text/x-python";
    map["texi"] = "text/x-texinfo";
    map["cdr"] = "application/vnd.corel-draw";
    map["rtx"] = "text/richtext";
    map["blender"] = "application/x-blender";
    map["cr2"] = "image/x-canon-cr2";
    map["sv4cpio"] = "application/x-sv4cpio";
    map["ksp"] = "application/x-kspread";
    map["oga"] = "audio/ogg";
    map["xmf"] = "audio/x-xmf";
    map["jar"] = "application/x-java-archive";
    map["theme"] = "application/x-theme";
    map["jad"] = "text/vnd.sun.j2me.app-descriptor";
    map["yml"] = "application/x-yaml";
    map["mrml"] = "text/x-mrml";
    map["ief"] = "image/ief";
    map["iptables"] = "text/x-iptables";
    map["tbz"] = "application/x-bzip-compressed-tar";
    map["dc"] = "application/x-dc-rom";
    map["123"] = "application/vnd.lotus-1-2-3";
    map["ged"] = "application/x-gedcom";
    map["dv"] = "video/dv";
    map["ssa"] = "text/x-ssa";
    map["gen"] = "application/x-genesis-rom";
    map["gem"] = "application/x-tar";
    map["emf"] = "image/x-emf";
    map["crw"] = "image/x-canon-crw";
    map["crt"] = "application/x-x509-ca-cert";
    map["gba"] = "application/x-gba-rom";
    map["oxt"] = "application/vnd.openofficeorg.extension";
    map["eml"] = "message/rfc822";
    map["metalink"] = "application/metalink+xml";
    map["tcl"] = "text/x-tcl";
    map["c++"] = "text/x-c++src";
    map["t2t"] = "text/x-txt2tags";
    map["emp"] = "application/vnd.emusic-emusic_package";
    map["stm"] = "audio/x-stm";
    map["bak"] = "application/x-trash";
    map["crl"] = "application/pkix-crl";
    map["rms"] = "application/vnd.rn-realmedia";
    map["txz"] = "application/x-xz-compressed-tar";
    map["arw"] = "image/x-sony-arw";
    map["rmx"] = "application/vnd.rn-realmedia";
    map["hpgl"] = "application/vnd.hp-hpgl";
    map["rmj"] = "application/vnd.rn-realmedia";
    map["qtl"] = "application/x-quicktime-media-link";
    map["rmm"] = "application/vnd.rn-realmedia";
    map["mup"] = "text/x-mup";
    map["movie"] = "video/x-sgi-movie";
    map["lua"] = "text/x-lua";
    map["dtx"] = "text/x-tex";
    map["qtif"] = "image/x-quicktime";
    map["C"] = "text/x-c++src";
    map["xslt"] = "application/xslt+xml";
    map["mof"] = "text/x-mof";
    map["js"] = "application/javascript";
    map["wv"] = "audio/x-wavpack";
    map["wp"] = "application/vnd.wordperfect";
    map["xbel"] = "application/x-xbel";
    map["sv4crc"] = "application/x-sv4crc";
    map["pcap"] = "application/vnd.tcpdump.pcap";
    map["xwd"] = "image/x-xwindowdump";
    map["vrm"] = "model/vrml";
    map["cur"] = "image/x-win-bitmap";
    map["c"] = "text/x-csrc";
    map["viv"] = "video/vivo";
    map["tlz"] = "application/x-lzma-compressed-tar";
    map["etx"] = "text/x-setext";
    map["wb1"] = "application/x-quattropro";
    map["xlam"] = "application/vnd.ms-excel.addin.macroEnabled.12";
    map["sty"] = "text/x-tex";
    map["cob"] = "text/x-cobol";
    map["tbz2"] = "application/x-bzip-compressed-tar";
    map["pdf"] = "application/pdf";
    map["pdc"] = "application/x-aportisdoc";
    map["pdb"] = "application/x-palm-database";
    map["xltm"] = "application/vnd.ms-excel.template.macroEnabled.12";
    map["markdown"] = "text/x-markdown";
    map["kwd"] = "application/x-kword";
    map["iso9660"] = "application/x-cd-image";
    map["tgz"] = "application/x-compressed-tar";
    map["pot"] = "text/x-gettext-translation-template";
    map["por"] = "application/x-spss-por";
    map["tga"] = "image/x-tga";
    map["m15"] = "audio/x-mod";
    map["kwt"] = "application/x-kword";
    map["xslfo"] = "text/x-xslfo";
    map["cs"] = "text/x-csharp";
    map["diff"] = "text/x-patch";
    map["m4u"] = "video/vnd.mpegurl";
    map["rpm"] = "application/x-rpm";
    map["ppsx"] = "application/vnd.openxmlformats-officedocument.presentationml.slideshow";
    map["jnlp"] = "application/x-java-jnlp-file";
    map["ps"] = "application/postscript";
    map["mpga"] = "audio/mpeg";
    map["swm"] = "application/x-ms-wim";
    map["pw"] = "application/x-pw";
    map["py"] = "text/x-python";
    map["rgb"] = "image/x-rgb";
    map["swf"] = "application/x-shockwave-flash";
    map["rmvb"] = "application/vnd.rn-realmedia";
    map["pk"] = "application/x-tex-pk";
    map["xac"] = "application/x-gnucash";
    map["po"] = "text/x-gettext-translation";
    map["pl"] = "application/x-perl";
    map["pm"] = "application/x-perl";
    map["oth"] = "application/vnd.oasis.opendocument.text-web";
    map["xlsx"] = "application/vnd.openxmlformats-officedocument.spreadsheetml.sheet";
    map["wk1"] = "application/vnd.lotus-1-2-3";
    map["kdelnk"] = "application/x-desktop";
    map["otc"] = "application/vnd.oasis.opendocument.chart-template";
    map["sldx"] = "application/vnd.openxmlformats-officedocument.presentationml.slide";
    map["otf"] = "application/x-font-otf";
    map["otg"] = "application/vnd.oasis.opendocument.graphics-template";
    map["imy"] = "text/x-iMelody";
    map["bmp"] = "image/bmp";
    map["xlsm"] = "application/vnd.ms-excel.sheet.macroEnabled.12";
    map["xmi"] = "text/x-xmi";
    map["f95"] = "text/x-fortran";
    map["otp"] = "application/vnd.oasis.opendocument.presentation-template";
    map["ots"] = "application/vnd.oasis.opendocument.spreadsheet-template";
    map["ott"] = "application/vnd.oasis.opendocument.text-template";
    map["dotm"] = "application/vnd.ms-word.template.macroEnabled.12";
    map["ppsm"] = "application/vnd.ms-powerpoint.slideshow.macroEnabled.12";
    map["csv"] = "text/csv";
    map["tsv"] = "text/tab-separated-values";
    map["lz"] = "application/x-lzip";
    map["p8"] = "application/pkcs8";
    map["mli"] = "text/x-ocaml";
    map["mpls"] = "video/mp2t";
    map["hdf"] = "application/x-hdf";
    map["gnd"] = "application/gnunet-directory";
    map["slk"] = "text/spreadsheet";
    map["au"] = "audio/basic";
    map["aif"] = "audio/x-aiff";
    map["mbox"] = "application/mbox";
    map["pack"] = "application/x-java-pack200";
    map["svgz"] = "image/svg+xml-compressed";
    map["aw"] = "application/x-applix-word";
    map["vapi"] = "text/x-vala";
    map["voc"] = "audio/x-voc";
    map["wp4"] = "application/vnd.wordperfect";
    map["wp5"] = "application/vnd.wordperfect";
    map["wp6"] = "application/vnd.wordperfect";
    map["3g2"] = "video/3gpp2";
    map["jpe"] = "image/jpeg";
    map["it"] = "audio/x-it";
    map["jpg"] = "image/jpeg";
    map["jpf"] = "image/jp2";
    map["jpx"] = "image/jp2";
    map["avi"] = "video/x-msvideo";
    map["vor"] = "application/vnd.stardivision.writer";
    map["wks"] = "application/vnd.ms-works";
    map["jpr"] = "application/x-jbuilder-project";
    map["texinfo"] = "text/x-texinfo";
    map["tzo"] = "application/x-tzo";
    map["shar"] = "application/x-shar";
    map["sami"] = "application/x-sami";
    map["pas"] = "text/x-pascal";
    map["spec"] = "text/x-rpm-spec";
    map["jceks"] = "application/x-java-jce-keystore";
    map["7z"] = "application/x-7z-compressed";
    map["html"] = "text/html";
    map["fo"] = "text/x-xslfo";
    map["pak"] = "application/x-pak";
    map["docbook"] = "application/docbook+xml";
    map["3gp"] = "video/3gpp";
    map["wpp"] = "application/vnd.wordperfect";
    map["jks"] = "application/x-java-keystore";
    map["wpl"] = "application/vnd.ms-wpl";
    map["kil"] = "application/x-killustrator";
    map["wpd"] = "application/vnd.wordperfect";
    map["wk3"] = "application/vnd.lotus-1-2-3";
    map["php"] = "application/x-php";
    map["wk4"] = "application/vnd.lotus-1-2-3";
    map["dat"] = "application/vnd.ms-tnef";
    map["mobi"] = "application/x-mobipocket-ebook";
    map["opml"] = "text/x-opml+xml";
    map["lzh"] = "application/x-lha";
    map["wmls"] = "text/vnd.wap.wmlscript";
    map["eps"] = "image/x-eps";
    map["k25"] = "image/x-kodak-k25";
    map["pict1"] = "image/x-pict";
    map["pict2"] = "image/x-pict";
    map["gsf"] = "application/x-font-type1";
    map["gsm"] = "audio/x-gsm";
    map["3gpp"] = "video/3gpp";
    map["cer"] = "application/pkix-cert";
    map["hpp"] = "text/x-c++hdr";
    map["dar"] = "application/x-dar";
    map["xspf"] = "application/xspf+xml";
    map["mo3"] = "audio/x-mo3";
    map["aiff"] = "audio/x-aiff";
    map["it87"] = "application/x-it87";
    map["aifc"] = "audio/x-aiff";
    map["not"] = "text/x-mup";
    map["shape"] = "application/x-dia-shape";
    map["bcpio"] = "application/x-bcpio";
    map["zoo"] = "application/x-zoo";
    map["ilbm"] = "image/x-ilbm";
    map["roff"] = "text/troff";
    map["rng"] = "application/xml";
    map["gmo"] = "application/x-gettext-translation";
    map["wb3"] = "application/x-quattropro";
    map["skr"] = "application/pgp-keys";
    map["m4v"] = "video/mp4";
    map["desktop"] = "application/x-desktop";
    map["cxx"] = "text/x-c++src";
    map["cue"] = "application/x-cue";
    map["adb"] = "text/x-adasrc";
    map["m4b"] = "audio/x-m4b";
    map["msod"] = "image/x-msod";
    map["m4a"] = "audio/mp4";
    map["bin"] = "application/octet-stream";
    map["rnc"] = "application/relax-ng-compact-syntax";
    map["psf"] = "audio/x-psf";
    map["xlm"] = "application/vnd.ms-excel";
    map["psd"] = "image/vnd.adobe.photoshop";
    map["bdmv"] = "video/mp2t";
    map["moc"] = "text/x-moc";
    map["ustar"] = "application/x-ustar";
    map["amr"] = "audio/AMR";
    map["psw"] = "application/x-pocket-word";
    map["mod"] = "audio/x-mod";
    map["vdr"] = "video/mpeg";
    map["sk1"] = "image/x-skencil";
    map["d"] = "text/x-dsrc";
    map["ChangeLog"] = "text/x-changelog";
    map["manifest"] = "text/cache-manifest";
    map["vda"] = "image/x-tga";
    map["PAR2"] = "application/x-par2";
    map["xsd"] = "application/xml";
    map["cls"] = "text/x-tex";
    map["vrml"] = "model/vrml";
    map["xsl"] = "application/xslt+xml";
    map["smaf"] = "application/x-smaf";
    map["vss"] = "application/vnd.visio";
    map["vst"] = "image/x-tga";
    map["vsw"] = "application/vnd.visio";
    map["webm"] = "video/webm";
    map["wwf"] = "application/x-wwf";
    map["vsd"] = "application/vnd.visio";
    map["ico"] = "image/vnd.microsoft.icon";
    map["for"] = "text/x-fortran";
    map["rdfs"] = "application/rdf+xml";
    map["dds"] = "image/x-dds";
    map["fodt"] = "application/vnd.oasis.opendocument.text-flat-xml";
    map["ica"] = "application/x-ica";
    map["kml"] = "application/vnd.google-earth.kml+xml";
    map["fodp"] = "application/vnd.oasis.opendocument.presentation-flat-xml";
    map["fods"] = "application/vnd.oasis.opendocument.spreadsheet-flat-xml";
    map["ac3"] = "audio/ac3";
    map["pem"] = "application/x-x509-ca-cert";
    map["x3f"] = "image/x-sigma-x3f";
    map["etheme"] = "application/x-e-theme";
    map["moov"] = "video/quicktime";
    map["ics"] = "text/calendar";
    map["fodg"] = "application/vnd.oasis.opendocument.graphics-flat-xml";
    map["ape"] = "audio/x-ape";
    map["3gpp2"] = "video/3gpp2";
    map["t"] = "text/troff";
    map["core"] = "application/x-core";
    map["dcl"] = "text/x-dcl";
    map["n64"] = "application/x-n64-rom";
    map["pls"] = "audio/x-scpls";
    map["m3u8"] = "application/vnd.apple.mpegurl";
    map["pla"] = "audio/x-iriver-pla";
    map["pln"] = "application/x-planperfect";
    map["rt"] = "text/vnd.rn-realtext";
    map["dcr"] = "image/x-kodak-dcr";
    map["bz"] = "application/x-bzip-compressed-tar";
    map["src"] = "application/x-wais-source";
    map["ppm"] = "image/x-portable-pixmap";
    map["obj"] = "application/x-tgif";
    map["ace"] = "application/x-ace";
    map["epsi"] = "image/x-eps";
    map["o"] = "application/x-object";
    map["idl"] = "text/x-idl";
    map["srt"] = "application/x-subrip";
    map["nds"] = "application/x-nintendo-ds-rom";
    map["kra"] = "application/x-krita";
    map["owl"] = "application/rdf+xml";
    map["uil"] = "text/x-uil";
    map["tiff"] = "image/tiff";
    map["nsc"] = "application/x-netshow-channel";
    map["h4"] = "application/x-hdf";
    map["h5"] = "application/x-hdf";
    map["pps"] = "application/vnd.ms-powerpoint";
    map["ppt"] = "application/vnd.ms-powerpoint";
    map["ppz"] = "application/vnd.ms-powerpoint";
    map["djvu"] = "image/vnd.djvu";
    map["nsv"] = "video/x-nsv";
    map["xpi"] = "application/x-xpinstall";
    map["mkd"] = "text/x-markdown";
    map["log"] = "text/x-log";
    map["mka"] = "audio/x-matroska";
    map["ppam"] = "application/vnd.ms-powerpoint.addin.macroEnabled.12";
    map["*"] = "text/x-makefile";
    map["awb"] = "audio/AMR-WB";
    map["mkv"] = "video/x-matroska";
    map["smil"] = "application/smil";
    map["xps"] = "application/oxps";
    map["wav"] = "audio/x-wav";
    map["lwo"] = "image/x-lwo";
    map["sdw"] = "application/vnd.stardivision.writer";
    map["sdp"] = "application/sdp";
    map["sds"] = "application/vnd.stardivision.chart";
    map["sxm"] = "application/vnd.sun.xml.math";
    map["hs"] = "text/x-haskell";
    map["hp"] = "text/x-c++hdr";
    map["sdd"] = "application/vnd.stardivision.impress";
    map["hh"] = "text/x-c++hdr";
    map["sda"] = "application/vnd.stardivision.draw";
    map["sdc"] = "application/vnd.stardivision.calc";
    map["e"] = "text/x-eiffel";
    map["Z"] = "application/x-tarz";
    map["dmg"] = "application/x-apple-diskimage";
    map["mts"] = "video/mp2t";
    map["sgml"] = "text/sgml";
    map["vivo"] = "video/vivo";
    map["dmp"] = "application/vnd.tcpdump.pcap";
    map["CREDITS"] = "text/x-credits";
    map["ui"] = "application/x-designer";
    map["hxx"] = "text/x-c++hdr";
    map["mtm"] = "audio/x-mod";
    map["vhd"] = "text/x-vhdl";
    map["oxps"] = "application/oxps";
    map["tnef"] = "application/vnd.ms-tnef";
    map["sxc"] = "application/vnd.sun.xml.calc";
    map["sxd"] = "application/vnd.sun.xml.draw";
    map["p7s"] = "application/pkcs7-signature";
    map["ag"] = "image/x-applix-graphics";
    map["sxg"] = "application/vnd.sun.xml.writer.global";
    map["ai"] = "application/illustrator";
    map["sxi"] = "application/vnd.sun.xml.impress";
    map["qif"] = "image/x-quicktime";
    map["lyx"] = "application/x-lyx";
    map["al"] = "application/x-perl";
    map["cbl"] = "text/x-cobol";
    map["ins"] = "text/x-tex";
    map["cbr"] = "application/x-cbr";
    map["as"] = "application/x-applix-spreadsheet";
    map["p7b"] = "application/x-pkcs7-certificates";
    map["cbt"] = "application/x-cbt";
    map["sxw"] = "application/vnd.sun.xml.writer";
    map["cbz"] = "application/x-cbz";
    map["lwob"] = "image/x-lwo";
    map["rvx"] = "video/vnd.rn-realvideo";
    map["mrl"] = "text/x-mrml";
    map["cmake"] = "text/x-cmake";
    map["gnuplot"] = "application/x-gnuplot";
    map["nb"] = "application/mathematica";
    map["nc"] = "application/x-netcdf";
    map["wb2"] = "application/x-quattropro";
    map["old"] = "application/x-trash";
    map["zabw"] = "application/x-abiword";
    map["gra"] = "application/x-graphite";
    map["php4"] = "application/x-php";
    map["php5"] = "application/x-php";
    map["tif"] = "image/tiff";
    map["php3"] = "application/x-php";
    map["wps"] = "application/vnd.ms-works";
    map["psid"] = "audio/prs.sid";
    map["dotx"] = "application/vnd.openxmlformats-officedocument.wordprocessingml.template";
    map["h++"] = "text/x-c++hdr";
    map["cb7"] = "application/x-cb7";
    map["sql"] = "text/x-sql";
    map["hwt"] = "application/x-hwt";
    map["hwp"] = "application/x-hwp";
    map["cpi"] = "video/mp2t";
    map["dvi"] = "application/x-dvi";
    map["icm"] = "application/vnd.iccprofile";
    map["svh"] = "text/x-svhdr";
    map["3gp2"] = "video/3gpp2";
    map["svg"] = "image/svg+xml";
    map["scala"] = "text/x-scala";
    map["potx"] = "application/vnd.openxmlformats-officedocument.presentationml.template";
    map["f90"] = "text/x-fortran";
    map["cacerts"] = "application/x-java-keystore";
    map["xbm"] = "image/x-xbitmap";
    map["xbl"] = "application/xml";
    map["icb"] = "image/x-tga";
    map["cpp"] = "text/x-c++src";
    map["m1u"] = "video/vnd.mpegurl";
    map["phps"] = "application/x-php";

    return map;
}
